@@ -67,7 +67,14 @@ class MachOStandalone(object):
             return res
 
     def copy_dylib(self, filename):
-        dest = os.path.join(self.dest, os.path.basename(filename))
+        # When the filename is a symlink use the basename of the target of the link
+        # as the name in standalone bundle. This avoids problems when two libraries
+        # link to the same dylib but using different symlinks.
+        if os.path.islink(filename):
+            dest = os.path.join(self.dest, os.path.basename(os.path.realpath(filename)))
+        else:
+            dest = os.path.join(self.dest, os.path.basename(filename))
+
         if not os.path.exists(dest):
             self.mergecopy(filename, dest)
         return dest
@@ -127,13 +134,12 @@ class MachOStandalone(object):
             if rewroteAny:
                 old_mode = flipwritable(fn)
                 try:
-                    f = open(fn, 'rb+')
-                    for header in node.headers:
-                        f.seek(0)
-                        node.write(f)
-                    f.seek(0, 2)
-                    f.flush()
-                    f.close()
+                    with open(fn, 'rb+') as f:
+                        for header in node.headers:
+                            f.seek(0)
+                            node.write(f)
+                        f.seek(0, 2)
+                        f.flush()
                 finally:
                     flipwritable(fn, old_mode)
 
